@@ -763,8 +763,8 @@ key		binding
 ;; Emacs -- don't autoload
 (unless (assq 'footnote-mode minor-mode-alist)
   (setq minor-mode-alist
-	(append minor-mode-alist
-		'(footnote-mode 'footnote-mode-line-string))))
+	(cons '(footnote-mode footnote-mode-line-string)
+	      minor-mode-alist)))
 
 (provide 'footnote)
 
